Thai ID Card Reader

📋

## Welcome to Thai ID Card Reader

Insert a Thai National ID card to begin reading.

### Instructions:

1. Ensure your card reader is connected
2. Insert your Thai National ID card
3. Data will be read automatically
4. Click any copy button to copy field data

## Card Information

📷

No Photo

Citizen ID (เลขประจำตัวประชาชน)
-
Name - Thai (ชื่อ-นามสกุล ไทย)
-
Name - English (ชื่อ-นามสกุล อังกฤษ)
-
Date of Birth (วันเกิด)
-
Gender (เพศ)
-
Address (ที่อยู่)
-
Issue Date (วันออกบัตร)
-
Expire Date (วันบัตรหมดอายุ)
-

### Event Log

--:--:-- Waiting for connection...